import React from 'react';
import { Button, Tabs, Form, Row, Col, InputNumber, message } from 'antd';
import { ModalForm, ProFormDigit, ProFormDependency } from '@ant-design/pro-components';
import { postTaCheckItem } from '@/service/tacheckitem';

const LocForm = (props) => {
  const {checkItem, open, onOpenChange, onChange} = props;

  const [form] = Form.useForm();

  const onFinish = async (values) => {
    const data = { ...(checkItem || {}), ...values, itemType: 'loc'}
    const res = await postTaCheckItem(data);
    onChange(res);
    return true;
  }

  const reset = () => {
    form.resetFields();
    form.setFieldsValue({ num: 1 });
  }

  React.useEffect(() => {
    if (checkItem) {
      form.setFieldsValue(checkItem);
    } else {
      reset();
    }
  }, [checkItem]);

  return (
    <ModalForm
      title={`${checkItem?.name} 维护`}
      width={600}
      open={open}
      form={form}
      onFinish={onFinish}
      onOpenChange={onOpenChange}
    >
      <ProFormDigit label="计分" name="fullScore" min={0.00} fieldProps={{precision: 2}} />
      <ProFormDigit label="数量" name="num" min={1} fieldProps={{precision: 0}} />
      <ProFormDependency name={['fullScore' , 'num']}>
        {
          ({fullScore, num}) => <ProFormDigit readonly label="分值" value={fullScore / num} fieldProps={{precision: 2}} />
        }        
      </ProFormDependency>
    </ModalForm>
  )
}

export default LocForm;
